#!/bin/bash

#
# Naming conventions
#

# workdir name
# usage: n_workdir BASE FUNC (OPTS)
function n_workdir {
	BASE=$1
	FUNC=$2
	OPT=$3
	printf "_cnt-%s-%s%s" "$BASE" "$FUNC" "$OPT" 
}

function base_of_workdir {
	echo "$1" | cut -d '-' -f 2
}

function func_of_workdir {
	echo "$1" | cut -d '-' -f 3
}

# these 4 names are imposed by "cdig -counters"
function n_ref     { echo "ref_$1.c"; }
function n_cptr  { echo "cptr_ref_$1.c"; }
function n_cptrloc { echo "ref_$1.cptrloc"; }
function n_looploc { echo "ref_$1.looploc"; }

# these names are local "cnt tool family" conventions
function n_pagai_res { echo "cptr_ref_$1.pagai.c"; }
function n_pagai_invs { echo "cptr_ref_$1.pagai.invs"; }
function n_elf  { echo "ref_$1.elf"; }
function n_lp  { echo "ref_$1.lp"; }
function n_cptr2bb { echo "ref_$1.cptr2bb"; }
function n_fixed_ffx { echo "ref_$1.fixed.ffx"; }
function n_orange_ffx { echo "ref_$1.orange.ffx"; }
function n_cptr2bb { echo "ref_$1.cptr2bb"; }

#
# init all vars when BASE is known ...
#
function init_vars {
	REF=$(n_ref $1)
	CPTR_REF=$(n_cptr $1)
	PAGAI_RES=$(n_pagai_res $1)
	PAGAI_INVS=$(n_pagai_invs $1)
	ELF=$(n_elf $1)
	LP=$(n_lp $1)
	CPTRLOC=$(n_cptrloc $1)
	LOOPLOC=$(n_looploc $1)
	CPTR2BB=$(n_cptr2bb $1)
	ORANGE_FFX=$(n_orange_ffx $1)
	FIXED_FFX=$(n_fixed_ffx $1)
	CPTR2BB=$(n_cptr2bb $1)
	BOUNDSLOG="bounds.log"
	PAGAI2LPLOG="pagai2lp.log"
}

#
# les couleurs xterm...
# ACTIVEES UNIQUEMENT SI TTY !
#
# check if stdout is a terminal...
export is_term_color=false
if test -t 1; then
	# see if it supports colors...
	ncolors=$(tput colors)
	if test -n "$ncolors" && test $ncolors -ge 8; then
		export is_term_color=true
		bold="$(tput bold)"
		underline="$(tput smul)"
		standout="$(tput smso)"
		normal="$(tput sgr0)"
		black="$(tput setaf 0)"
		red="$(tput setaf 1)"
		green="$(tput setaf 2)"
		yellow="$(tput setaf 3)"
		blue="$(tput setaf 4)"
		magenta="$(tput setaf 5)"
		cyan="$(tput setaf 6)"
		white="$(tput setaf 7)"
	fi
fi
function chcolor {
	if $is_term_color ; then
		for cmd in $@; do
			case $cmd in
			bold) tput bold;;
			underline) tput smul;;
			standout) tput smso;;
			normal) tput sgr0;;
			black) tput setaf 0;;
			red) tput setaf 1;;
			green) tput setaf 2;;
			# 3=yellow by dflt, =pink for me !
			yellow) tput setaf 3;;
			pink) tput setaf 3;;
			blue) tput setaf 4;;
			# 5=magenta by dflt, =purple for me !
			magenta) tput setaf 5;;
			purple) tput setaf 5;;
			# 6=cyan by dflt, =orange for me !
			cyan) tput setaf 6;;
			white) tput setaf 7;;
			esac	
		done
	fi
}

#
# Utiles pour faire des scripts interactifs
#
function echoerr { echo "$*" >&2; }

function error { echo -e "${red}$*${normal}" >&2; exit 2; }

function checkret {
   if [ $? != 0 ] ; then
      error "$1"
   fi
}
function checkcode {
	set +x
   if [ $1 != 0 ] ; then
      error "$2"
   fi
}

function checkfile {
	if [ ! -f "$1" ]; then
		printf "${red}$2${normal}\n" "$1" >&2
		exit 2
	fi
}

function checkcommand {
	if ! hash "$1" 2>/dev/null; then
		printf "${red}$2${NORMAL}\n" "$1" >&2
		exit 2
	fi
}

function yesno {
	if [ $# -lt 1 ]; then
		echo "usage: yesno <msg>" >&2
		return 2
	else
		msg=$1
		while [ 1 ]; do
			echo "$msg [Y/n] ?"
			read rep
			#echo rep=\"$rep\"
			case $rep in
				""|y|Y) return 0;;
				n|N) return 1;;
			esac
		done
	fi
}

function noyes {
	if [ $# -lt 1 ]; then
		echo "usage: noyes <msg>" >&2
		return 2
	else
		msg=$1
		while [ 1 ]; do
			echo "$msg [y/N] ?"
			read rep
			#echo rep=\"$rep\"
			case $rep in
				y|Y) return 0;;
				""|n|N) return 1;;
			esac
		done
	fi
}
